==> formatting-stack-beta-0.10.4.jar: META-INF/leiningen/net.vemv/formatting-stack-beta/project.clj <==
(def formatting-stack-dependencies
  '[[cljfmt "0.6.4"]
    [com.gfredericks/how-to-ns "0.2.2"]
    [com.gfredericks/lein-all-my-files-should-end-with-exactly-one-newline-character "0.1.1"]
    [com.stuartsierra/component "0.4.0"]
    [integrant "0.7.0"]
    [jonase/eastwood "0.3.5"]
    [lein-bikeshed "0.5.1"]
    [medley "1.1.0"]
    [org.clojure/clojure "1.9.0"]
    [org.clojure/tools.namespace "0.3.0-alpha4"]
    [org.clojure/tools.reader "1.1.1"]
    [refactor-nrepl "2.4.0"]])

(defproject net.vemv/formatting-stack-beta "0.10.4"
  :description "An efficient, smart, graceful composition of formatters, linters and such."
  :url "https://github.com/nedap/formatting-stack"
  :license {:name "Eclipse Public License"
            :url  "http://www.eclipse.org/legal/epl-v10.html"}
  :dependencies []
  :profiles {
             #_    #_ :auth {:dependencies ~(conj formatting-stack-dependencies
                                                  ;; dependency of `refactor-nrepl`, which `refactor-nrepl` excludes
                                                  '[cider/cider-nrepl "0.18.0"])}
             :dev  {:source-paths ["dev"]
                    :dependencies ~(vary-meta (conj formatting-stack-dependencies
                                                    ;; downgrade since I use a legacy CIDER config in my Emacs
                                                    '[cider/cider-nrepl "0.16.0"])
                                              assoc :replace false)}
             ;; `dev` in :test is important - a test depends on it:
             :test {:source-paths ["dev"]}})

==> formatting-stack-beta-0.10.5.jar: META-INF/leiningen/net.vemv/formatting-stack-beta/project.clj <==
(def formatting-stack-dependencies
  '[[cljfmt "0.6.4"]
    [com.gfredericks/how-to-ns "0.2.2"]
    [com.gfredericks/lein-all-my-files-should-end-with-exactly-one-newline-character "0.1.1"]
    [com.stuartsierra/component "0.4.0"]
    [integrant "0.7.0"]
    [jonase/eastwood "0.3.5"]
    [lein-bikeshed "0.5.1"]
    [medley "1.1.0"]
    [org.clojure/clojure "1.9.0"]
    [org.clojure/tools.namespace "0.3.0-alpha4"]
    [org.clojure/tools.reader "1.1.1"]
    [refactor-nrepl "2.4.0"]])

(defproject net.vemv/formatting-stack-beta "0.10.5"
  :description "An efficient, smart, graceful composition of formatters, linters and such."
  :url "https://github.com/nedap/formatting-stack"
  :license {:name "Eclipse Public License"
            :url  "http://www.eclipse.org/legal/epl-v10.html"}
  :dependencies []
  :profiles {
             :foo  {:dependencies ~(conj formatting-stack-dependencies
                                         ;; dependency of `refactor-nrepl`, which `refactor-nrepl` excludes
                                         '[cider/cider-nrepl "0.18.0"])}
             :dev  {:source-paths ["dev"]
                    :dependencies ~(vary-meta (conj formatting-stack-dependencies
                                                    ;; downgrade since I use a legacy CIDER config in my Emacs
                                                    '[cider/cider-nrepl "0.16.0"])
                                              assoc :replace false)}
             ;; `dev` in :test is important - a test depends on it:
             :test {:source-paths ["dev"]}})
